cgexplore.utilities.AtomliteDatabase
====================================

.. currentmodule:: cgexplore.utilities

.. autoclass:: AtomliteDatabase
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~AtomliteDatabase.add_entries
      ~AtomliteDatabase.add_molecule
      ~AtomliteDatabase.add_properties
      ~AtomliteDatabase.get_database
      ~AtomliteDatabase.get_entries
      ~AtomliteDatabase.get_entry
      ~AtomliteDatabase.get_molecule
      ~AtomliteDatabase.get_num_entries
      ~AtomliteDatabase.get_num_property_entries
      ~AtomliteDatabase.get_property
      ~AtomliteDatabase.get_property_df
      ~AtomliteDatabase.get_property_entries
      ~AtomliteDatabase.get_property_entry
      ~AtomliteDatabase.has_molecule
      ~AtomliteDatabase.keep_if
      ~AtomliteDatabase.remove_entry
      ~AtomliteDatabase.remove_property
      ~AtomliteDatabase.set_property
   
   

   
   
   